@@ -132,14 +132,14 @@ c
                el=(h-z0)/n
                x=x0+ el*l
                y=y0+ el*m
-               if(x**2 + y**2 .le. rsq  .and. el .gt. 0.) then
+               if(x**2 + y**2 .le. rsq  .and. el .ge. 0.) then
                   icon2 = 1
                endif
            elseif(n .lt. 0.d0 .and. icon .eq. 0) then
                el=-z0/n
                x=x0+ el*l
                y=y0+ el*m
-               if(x**2 + y**2 .le. rsq .and. el .gt. 0. ) then
+               if(x**2 + y**2 .le. rsq .and. el .ge. 0. ) then
                   icon2 = 6
                endif
            endif
@@ -172,14 +172,14 @@ c                       point is inner part of cylinder
                      el=  (-b1 + ds)/wxy
                      z=z0+el*n
                      if(z0 .ge. 0. .and. z0 .le. h 
-     *                   .and. el .gt. 0.) then
+     *                   .and. el .ge. 0.) then
                         icon = 0
                         icon2 = 2
                      elseif(z0 .gt. h .and. n .lt. 0.d0) then
                         el=(h-z0)/n
                         x=x0+el*l
                         y=y0+el*m
-                        if(x**2+ y**2 .le. rsq .and.  el .gt. 0. ) then
+                        if(x**2+ y**2 .le. rsq .and.  el .ge. 0. ) then
                            icon = 1
                            icon2 = 1
                         endif
@@ -187,7 +187,7 @@ c                       point is inner part of cylinder
                         el=-z0/n
                         x=x0+el*l
                         y=y0+el*m
-                        if(x**2+ y**2 .le. rsq .and. el .gt. 0.) then
+                        if(x**2+ y**2 .le. rsq .and. el .ge. 0.) then
                            icon =  1
                            icon2 = 6
                         endif
@@ -197,14 +197,14 @@ c                       point is outside.  x-ssing forward with cyl
                       el=  (-b1- ds)/wxy
                       z=z0+el*n
                       if(z .ge. 0. .and. z .le. h 
-     *                   .and. el .gt. 0. ) then
+     *                   .and. el .ge. 0. ) then
                          icon = 1
                          icon2 = 2
                       elseif(n .lt. 0.d0) then
                          el=(h-z0)/n
                          x=x0+el*l
                          y=y0+el*m
-                         if(x**2+ y**2 .le. rsq .and. el .gt. 0. ) then
+                         if(x**2+ y**2 .le. rsq .and. el .ge. 0. ) then
                             icon = 1
                             icon2 = 1
                          endif
@@ -212,7 +212,7 @@ c                       point is outside.  x-ssing forward with cyl
                          el=-z0/n
                          x=x0+el*l
                          y=y0+el*m
-                         if(x**2+ y**2 .le. rsq .and. el .gt. 0. ) then
+                         if(x**2+ y**2 .le. rsq .and. el .ge. 0. ) then
                             icon = 1
                             icon2 = 6
                          endif
