@@ -44,15 +44,14 @@ c            generate a random point distributed on the
 c            surface of a sphere with a Gaussian density.(Note below)
 c            Points are distributed around
 c            given polar angles (teta, phi) within a given opening angle
-c            (oa).  Actually, the point is put little bit inside of
-c            the exact surface so that the point is guaranteed inside
-c            or on the surface of the sphere.
-c                 
+c            (oa).  
+
 c Note:   Gaussian means that the beam has a Gaussian density if it is
 c    projected to the plane which is tangent to the sphere at the
 c    Gaussian center.
 c    The rcut used for epGaussb is related to oa here as
 c    rcut = r sin( oa ).
+c ****** If hwhm is negative, uniform distribution is assumed instead of Gauss.
 c
       integer ini               ! input
                       !  1-->  teta and phi are different from
@@ -61,6 +60,7 @@ c
                       !        the previous call.
       real*8  hwhm      ! input.  half width at half maximum of the
                         !      Gaussian density beam.
+              ! if negative, uniform beam is taken
       real*8  rin       ! input.  radius of the sphere
       real*8  teta      ! input.  polar angle in degree
       real*8  phi       ! input.  azimutal angle in degree
@@ -71,23 +71,32 @@ c
       record /fmom/ xyz, xyz2
       real*8  a(4, 4), b(4, 4), ba(4, 4)
 
-      real*8  rcut, x, y, z, z2, r
+      real*8  rcut, x, y, z, z2, r, temp, u, fsin, fcos
       save ba
 
-      r = rin - EpsLeng
+      r = rin 
       if(ini .eq. 1) then
          call cgetRotMat4(2, -teta*Torad, a)
          call cgetRotMat4(3, -phi*Torad, b)
          call cmultRotMat4(b, a, ba)
       endif
       rcut = r *sin(oa*Torad)
-      call epGaussb(hwhm, rcut, x, y)
-      z2= r**2 - (x**2 + y**2)
-      if(z2 .lt. 0.) then
-         call cerrorMsg(
-     *  'opening angle for epgonShpere should be checked', 0)
+      if(hwhm .ge. 0.0) then
+         call epGaussb(hwhm, rcut, x, y)
+         z2= r**2 - (x**2 + y**2)
+         if(z2 .lt. 0.) then
+            call cerrorMsg(
+     *           'opening angle for epgonShpere should be checked', 0)
+         endif
+         z = sqrt(z2)
+      else
+         call kcossn(fcos, fsin)
+         call rndc(u)
+         temp = rcut *  sqrt(u)
+         x = temp * fcos
+         y = temp * fsin 
+         z =  sqrt(r**2 - x**2-y**2)
       endif
-      z = sqrt(z2)
       xyz.p(1) = x
       xyz.p(2) = y
       xyz.p(3) = z
@@ -131,7 +140,7 @@ c
       real*8 fcos,  fsin
       save ba
 
-      r = rin - EpsLeng
+      r = rin 
       if(ini .eq. 1) then
          call cgetRotMat4(2, -teta*Torad, a)
          call cgetRotMat4(3, -phi*Torad, b)
@@ -178,7 +187,7 @@ c                                 sphere center is assumed to be at the origin.
       real*8 fcos,  fsin, r, u
 
 
-      r = rin - EpsLeng
+      r = rin 
 
       call kcossn(fcos, fsin)
       call rndc(u)
@@ -206,19 +215,12 @@ c             *** until loop***
    10        continue
        end
 c        ************************* real*8 data
-       subroutine arprmr(io, vname, x)
+       subroutine arprmr(vvalue, x)
         implicit none
         integer io
-        character*(*) vname
+        character*(*) vvalue
         real*8 x
-
-        character*120 dat
-        integer lc
-c          skip comment lines and get a data line. 
-        call epgetdatline(io, dat, 0)
-        lc = index(dat(2:120), ' ') 
-        read(dat(lc+1:120), *)   x, x
-        call anamec(vname, dat(2:lc))
+        read(vvalue, *)   x, x
         end
 
 c     *******************************
@@ -257,82 +259,32 @@ c         check if "/" exists for safety
          
       end   
 c     ************************* complex data
-      subroutine arprmm(io, vname, c)
+      subroutine arprmm(vvalue, c)
       implicit none
-      integer io
-      character*(*) vname
+      character*(*) vvalue
       complex*16 c
-          
-      character*120 dat
-      integer lc, eof 
-
-      if(vname(2:6) .eq. 'range') then
-         eof =1
-         call epgetdatline(io, dat, eof)
-         if(eof .eq. 2) then
-            dat =' '//vname(1:1)//'range (0., 0.) /'
-         endif
-      else
-         call epgetdatline(io, dat, 0)
-      endif
-      lc = index(dat(2:120), ' ')
-      read(dat(lc+1:120), *)   c, c
-      call anamec(vname, dat(2:lc))
+      read( vvalue, *)   c, c
       end
 c     ************************ integer data
-      subroutine arprmi(io, vname, i)
+      subroutine arprmi(vvalue, i)
       implicit none
-      integer io
-      character*(*) vname
+      character*(*) vvalue
       integer i
-          
-      character*120 dat
-      integer lc
-
-      call epgetdatline(io, dat, 0)
-      lc = index(dat(2:120), ' ')  
-      read(dat(lc+1:120), *)   i,i
-      call anamec(vname, dat(2:lc))
+      read(vvalue, *)   i,i
       end
 c        ************************* character data
-      subroutine arprmc(io, vname, cha)
+      subroutine arprmc(vvalue, cha)
       implicit none
-      integer io
-      character*(*) vname
+      character*(*) vvalue
       character*(*) cha
-          
-      character*120 dat
-      integer lc, eof
-
-      if(vname .eq. 'epHooks') then
-c                     this should be  the last part
-c            may not be given
-         eof = 1
-         call epgetdatline(io, dat, eof)
-         if(eof .eq. 2) then
-            dat = " epHooks '0 0 0' /"
-         endif
-      else
-         call epgetdatline(io, dat, 0)
-      endif
-      lc = index(dat(2:120), ' ') 
-      read(dat(lc+1:120), *)  cha, cha
-      call anamec(vname, dat(2:lc))
+      read(vvalue, *)  cha, cha
       end
 c        ***************************** logical data
-      subroutine arprml(io, vname, logi)
+      subroutine arprml(vvalue, logi)
       implicit none
-      integer io
-      character*(*) vname
+      character*(*) vvalue
       logical logi
-          
-      character*120 dat
-      integer lc
-
-      call epgetdatline(io, dat, 0)
-      lc = index(dat(2:120), ' ') 
-      read(dat(lc+1:120), *)  logi, logi
-      call anamec(vname, dat(2:lc))
+      read(vvalue, *)  logi, logi
       end     
 c        ---------------------------------------------
       subroutine awprmr(io, vname, x)
@@ -439,4 +391,35 @@ c         call cerrorMsg('out of range request to epqHookr',0)
          rv = epHookr(i)
       endif
       end
-
+      logical function epgetParmN( io,  vname, vv )
+c          get parameter variable name and given value(s)  from io
+      implicit none
+       integer io
+       character*(*)  vname, vv  ! output
+       integer linel
+       parameter( linel = 100)
+       character*(linel)  line
+       integer loc, loc2
+       vname = " "
+       do while(.true.)
+          read(io, '(a)', end=100 ) line
+          if( line(1:1) .eq. " " .and. line(2:2) .ne. " ") then
+             loc = index( line(3:linel), " ")  + 2
+             vname = line(2:loc-1)
+             loc2 = index( line, "/")
+             if(loc2 .eq. 0 ) then
+                write(0,* ) ' "/"  is missing in the input data file '
+                write(0,*)  ' The line is: ', line
+                stop 1234
+             endif
+             vv = line(loc+1:linel)  !  some data containes '/' such as '../../Media' so put all
+                                     ! data.
+             goto 50
+          endif
+       enddo
+ 50    continue
+       epgetParmN = .true.
+       return
+ 100   continue
+       epgetParmN =.false.
+       end
