@@ -116,6 +116,7 @@ c            push Cosmos made ptlcs in the stack area
       nTrack.pos.y = cTrack.pos.y
       nTrack.pos.z = cTrack.pos.z
       nTrack.t = cTrack.t
+      nTrack.user = cTrack.user
       nTrack.cn = cTrack.cn
 
       do i = 1, Nproduced
@@ -267,12 +268,10 @@ c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
       endif
 
       call epgetxs(ActiveMdl, TrackBefMove.p, media, xs, icon)
-
       if(icon .eq. 0) then
-         mfp = toabn*media.A/xs ! in kg/m^2
+         mfp = toabn*media.A/xs ! in kg/m^2   . meida.A is OK even if it may look small 
          call rndc(u)
          collkgram = -mfp*log(u)
-
       elseif(icon .eq. -1) then
          collkgram = Infty
       elseif(icon .eq. 1) then
@@ -295,4 +294,3 @@ c  &&&&
       end
 
 
-
