@@ -46,7 +46,16 @@ c
      *   cosmosparam
 
         call sparmr(SepicsFile)
-
+c          check DCInp
+        if(InputA .eq. 'fix') then
+           if(abs( DCInp.x**2 + DCInp.y**2 + DCInp.z**2 - 1.d0)
+     *        .gt. 1.d-3) then
+              call cerrorMsg('sum of DCInp**2 is far from 1', 0)
+           else
+c              normalize so
+              call epadjdir(DCInp)
+           endif
+        endif
 c
 c                   init epics
         if(cosmosparam .ne. ' ') then
@@ -207,6 +216,7 @@ c         ---------------- Error -----------------
        implicit none
 #include  "ZsepManager.h"
 #include  "ZepTrack.h"
+#include  "Zsparm.h"
 #include  "Zcode.h"
        record /epTrack/ aTrack
        integer  icon  ! output. 0  -- go ahead.   1-- call  this again to set multiple 1ries
@@ -308,11 +318,19 @@ c         nf many not be equal to fc. but must be nf >= fc
           aTrack.pos.x = xin
           aTrack.pos.y = yin
           aTrack.pos.z = zin
+c            for safety
+          PosInp.x = xin
+          PosInp.y = yin
+          PosInp.z = zin
        endif
        if(Inpdir .eq. 1) then
           aTrack.w.x = wx
           aTrack.w.y = wy
           aTrack.w.z = wz
+c            for safety also set next
+          DCInp.x = wx
+          DCInp.y = wy
+          DCInp.z = wz
        endif
        aTrack.p.fm.p(4)  =  erg
        if(Inperg .eq. 1) then
@@ -428,14 +446,16 @@ c            multiple particles are incident; icon = 1--> end of a bunch
 #include  "Zep3Vec.h"
 #include  "Zswk.h"
 #include  "Zsparm.h"
+#include  "Zglobalc.h"
       
       record /epTrack/ aTrack
       record /epTrack/InciTrack, bTrack
       integer ns, i, j, icon
       logical ok
-      integer ntry
-      real*8 sume
+      real*8 sume, theta, phi, r
       record /epPos/ org, rxyz
+      record /epDirec/ norm
+      character*40 msg
 
 
 
@@ -452,52 +472,79 @@ c               fix energy (momentum yet)
 c               fix position
       ok = .false.
 
-      ntry =0
 
-      do while (.not. ok)
+c      do while (.not. ok)
          if(Inpxyz .eq. 0) then
             call sfixp(aTrack)
          endif
 c               fix angle
          if(Inpdir .eq. 0) then
-            call sfixa(aTrack, ok)
-            if(ok .and. InputP(1:3) .eq. 'sph') then
-c                  pos is not yet fixed.              
-               call epqwcoord(org, rxyz)
-               call epuSphere(rxyz.x, aTrack.w,
-     *           aTrack.pos)
-               aTrack.pos.x= aTrack.pos.x + org.x
-               aTrack.pos.y= aTrack.pos.y + org.y
-               aTrack.pos.z= aTrack.pos.z + org.z
-            endif
-         elseif(InputP(2:4) .eq. 'sph' .or.
-     *     InputP(1:3) .eq. 'sph' ) then
-            call epqwcoord(org, rxyz)
-            if(InputP(1:3) .eq. 'sph' ) then
-               call epuSphere(rxyz.x, aTrack.w,
-     *           aTrack.pos)
-               aTrack.pos.x= aTrack.pos.x + org.x
-               aTrack.pos.y= aTrack.pos.y +  org.y
-               aTrack.pos.z= aTrack.pos.z +  org.z
-               ok = .true.
-            else
-               ok =aTrack.w.x*(aTrack.pos.x -org.x)+
-     *          aTrack.w.y*(aTrack.pos.y -org.y)+
-     *          aTrack.w.z*(aTrack.pos.z -org.z) .lt. 0.
-            endif
-c/////////////
-c            if(.not. ok) then
-c               ntry = ntry +1
-c               if(ntry .gt. 10000) then
-c                  write(0,*) ' ntry=',ntry, ' wz=',aTrack.w.z
-c                  stop 9999
-c               endif
-c            endif
-c//////////////////
-         else
-            ok =.true.
+            call sfixa(aTrack)
          endif
-      enddo
+         if(Inpxyz .eq. 0.) then
+            if(InputP .eq. 'fix') then
+               aTrack.pos=PosInp
+            elseif(InputP .eq. 'usph' .or. InputP .eq. 'g->sph'
+     *           .or. InputP .eq. 'u->sph' ) then
+c                normal vector is the particle position to the center
+               call epqwcoord(org, rxyz)
+               norm.x =-( aTrack.pos.x - org.x )
+               norm.y =-( aTrack.pos.y - org.y )
+               norm.z =-( aTrack.pos.z - org.z )
+               call epadjdir(norm)
+c                  convert direction cos to world coord.
+               call ctransVectZ(norm, DCInp, aTrack.w)
+            elseif(InputP(2:3) .eq. '+z') then
+               aTrack.w.x = DCInp.x
+               aTrack.w.y = DCInp.y
+               aTrack.w.z = DCInp.z
+            elseif(InputP(2:3) .eq. '-z') then
+               aTrack.w.x = DCInp.x
+               aTrack.w.y = DCInp.y
+               aTrack.w.z = -DCInp.z
+            elseif(InputP(2:3) .eq. '+y') then              
+               aTrack.w.x = DCInp.x
+               aTrack.w.y = DCInp.z
+               aTrack.w.z = DCInp.y
+            elseif(InputP(2:3) .eq. '-y') then              
+               aTrack.w.x = DCInp.x
+               aTrack.w.y = -DCInp.z
+               aTrack.w.z = DCInp.y
+            elseif(InputP(2:3) .eq. '+x') then              
+               aTrack.w.x = DCInp.z
+               aTrack.w.y = DCInp.x
+               aTrack.w.z = DCInp.y
+            elseif(InputP(2:3) .eq. '-x') then              
+               aTrack.w.x = -DCInp.z
+               aTrack.w.y = DCInp.x
+               aTrack.w.z = DCInp.y
+            elseif(InputP .eq. 'g->sph2'
+     *        .or. InputP .eq. 'u->sph2' ) then
+c
+c              DCInp gives teta and phi .  opening angle is 90 deg
+               call epqwcoord(org, rxyz)
+                            ! rxyz.x= should be the radius of the sphere
+               r = rxyz.x -EpsLeng
+               theta = acos(-DCInp.z)*Todeg
+               phi = atan2(-DCInp.y, -DCInp.x)*Todeg
+               if(InputP .eq. 'g->sph2') then
+                  call epgonSphere(1, Hwhm, r, 
+     *              theta, phi, 90.0d0, aTrack.pos)
+               else
+                  call epgonSphere(1, -1.0d0, r, 
+     *              theta, phi, 90.0d0, aTrack.pos)
+               endif
+               aTrack.pos.x = aTrack.pos.x + org.x
+               aTrack.pos.y = aTrack.pos.y + org.y
+               aTrack.pos.z = aTrack.pos.z + org.z
+               aTrack.w = DCInp
+            else
+               write(msg,*)' InputP=',InputP, ' and ',
+     *             InputA,' incompatible'
+               call cerrorMsg(msg, 0)
+            endif
+         endif
+c      enddo
 c               fix others
 
       call sfixo(aTrack)
@@ -564,7 +611,7 @@ c             get  current random no.
       subroutine sfixe(aTrack)
        implicit none
 #include  "ZsepManager.h"
-#include  "Zglobalc.h"
+
 #include  "ZepTrack.h"
 #include  "ZepTrackp.h"
 #include  "Zep3Vec.h"
@@ -602,8 +649,8 @@ c          sample incident x,y,z position;  world coord.
 #else
           aTrack.pos = PosInp
 #endif
-       elseif(InputP(1:2) .eq. 'u-' .or.
-     *        InputP(1:2) .eq. 'u+' ) then
+       elseif( (InputP(1:2) .eq. 'u-' .and. InputP(1:3) .ne. 'u->')
+     *       .or.   InputP(1:2) .eq. 'u+' ) then
 c            uniform in Xrange, Yrange,  Zrange        
           call rndc(u)
           aTrack.pos.x
@@ -619,7 +666,6 @@ c            uniform in Xrange, Yrange,  Zrange
      *          + real(Zrange)
 
        elseif(InputP .eq. 'usph') then
-c                 InputP = 'usph'
           call epqwcoord(org, rxyz)
                          ! rxyz.x= should be the radius of the sphere
           r = rxyz.x -EpsLeng
@@ -629,11 +675,15 @@ c                                  teta       phi      o.a
           aTrack.pos.x = aTrack.pos.x + org.x
           aTrack.pos.y = aTrack.pos.y + org.y
           aTrack.pos.z = aTrack.pos.z + org.z
-       elseif(InputP .eq. 'gsph') then
+c            angle is later fixed.
+       elseif(InputP .eq. 'g->sph') then
 c
 c           PosInp.x = teta, PosInp.y = phi, PosInp.z = opening angl
-c           ProfR should be  R * sin(O.A), but not referred.
-c
+c           Instead of ProfR,  R * sin(O.A) is used.
+c     
+          if(PosInp.z .gt. 90.) then
+             call cerrorMsg("Zinp > 90 for InputP=g->sph", 0)
+          endif
           call epqwcoord(org, rxyz)
                             ! rxyz.x= should be the radius of the sphere
           r = rxyz.x -EpsLeng
@@ -644,9 +694,30 @@ c
           aTrack.pos.x = aTrack.pos.x + org.x
           aTrack.pos.y = aTrack.pos.y + org.y
           aTrack.pos.z = aTrack.pos.z + org.z
-       elseif(InputP(1:3) .eq. 'sph') then
-c               this case you have to InpDir!=0
-c            wait until angle is given                   
+c            angle is later fixed.
+       elseif(InputP .eq. 'g->sph2') then
+c               this case you  InpDir!=0 or DCInp must be given
+c               wait until angle is given                   
+       elseif(InputP .eq. 'u->sph') then
+          if(PosInp.z .gt. 90.) then
+             call cerrorMsg("Zinp > 90 for InputP=u->sph", 0)
+          endif
+          call epqwcoord(org, rxyz)
+                            ! rxyz.x= should be the radius of the sphere
+          r = rxyz.x -EpsLeng
+c            For  negative HWHM, uniform distribution is employed
+          call epgonSphere(1, -1.0d0, r, PosInp.x, PosInp.y, PosInp.z,
+     *       aTrack.pos)
+
+          aTrack.pos.x = aTrack.pos.x + org.x
+          aTrack.pos.y = aTrack.pos.y + org.y
+          aTrack.pos.z = aTrack.pos.z + org.z
+c            angle is later fixed.
+c  
+       elseif( InputP .eq. 'u->sph2') then
+c               this case  InpDir!=0 or DCInp must be given
+c               wait until angle is given                   
+c  
        elseif(InputP(1:1) .eq. 'g') then
 c                  gaussian density beam
           call epGaussb(Hwhm, ProfR, dx, dy)
@@ -665,28 +736,20 @@ c                 around Xinp, Yinp
              aTrack.pos.z = PosInp.z + dy
           else
              write(msg,*) ' InputP=',InputP, ' invalid'
-             call cerrorMsg(msg,  0)
+             call cerrorMsg(msg,  1)
+             call cerrorMsg("see sepicsfile in FirstKiss",0)
           endif
        else
           write(msg,*) ' InputP=',InputP, ' invalid'
-          call cerrorMsg(msg,  0)
+          call cerrorMsg(msg,  1)
+          call cerrorMsg("see sepicsfile in FirstKiss",0)
        endif
        return
 c       ****************************************
-        entry sfixa(aTrack, ok)
-c          
-        ok = .true.
-        if(InputA .eq. 'fix') then
-           aTrack.w.x = DCInp.x
-           aTrack.w.y = DCInp.y
-           aTrack.w.z = DCInp.z
-           if(abs( DCInp.x**2 + DCInp.y**2 + DCInp.z**2 - 1.d0)
-     *        .gt. 1.d-3) then
-              call cerrorMsg('sum of DCInp**2 is far from 1', 0)
-           else
-c              normalize so
-              call epadjdir(aTrack.w)
-           endif
+        entry sfixa(aTrack)
+c          DCInp is fixed. aTrack.w is not yet  given
+        if(InputA .eq. 'fix' ) then
+c          nothing to do; DCInp is used.
         else
            if(InputA .eq. 'is') then
               call rndc(u)
@@ -697,12 +760,12 @@ c              normalize so
               call rndc(u)
               if(pw .ne. -1.d0) then
                  DCInp.z=
-     *          ( (IMAG_P(CosNormal)**(pw+1.d0) - 
-     *                  real(CosNormal)**(pw+1.d0))* u
-     *           + real(CosNormal)**(pw+1.d0))**(1.d0/(pw+1.d0))
+     *             ( (IMAG_P(CosNormal)**(pw+1.d0) - 
+     *             real(CosNormal)**(pw+1.d0))* u
+     *             + real(CosNormal)**(pw+1.d0))**(1.d0/(pw+1.d0))
               else
                  DCInp.z =(IMAG_P(CosNormal)/real(CosNormal))**u *
-     *                  real(CosNormal)
+     *             real(CosNormal)
               endif
            else
               write(msg,*) ' InputA=',InputA, ' not supported'
@@ -712,56 +775,6 @@ c              normalize so
            st= sqrt( 1.d0 - DCInp.z**2)
            DCInp.x = st * cs
            DCInp.y = st * sn
-
-           if(InputP .eq. 'fix') then
-              aTrack.w.x = DCInp.x
-              aTrack.w.y = DCInp.y
-              aTrack.w.z = DCInp.z
-           elseif(InputP .eq. 'usph' .or.
-     *            InputP .eq. 'gsph' ) then
-              if( DCInp.x*(aTrack.pos.x -org.x)+ 
-     *            DCInp.y*(aTrack.pos.y -org.y)+ 
-     *            DCInp.z*(aTrack.pos.z -org.z) .lt. 0.) then
-                 aTrack.w.x = DCInp.x
-                 aTrack.w.y = DCInp.y
-                 aTrack.w.z = DCInp.z
-               else
-                 ok = .false.
-c                 aTrack.w.x = -DCInp.x
-c                 aTrack.w.y = -DCInp.y
-c                 aTrack.w.z = -DCInp.z
-              endif                 
-
-c              direct the angle around the normal vector
-           elseif(InputP(2:3) .eq. '+z') then
-              aTrack.w.x = DCInp.x
-              aTrack.w.y = DCInp.y
-              aTrack.w.z = DCInp.z
-           elseif(InputP(2:3) .eq. '-z') then
-              aTrack.w.x = DCInp.x
-              aTrack.w.y = DCInp.y
-              aTrack.w.z = -DCInp.z
-           elseif(InputP(2:3) .eq. '+y') then              
-              aTrack.w.x = DCInp.x
-              aTrack.w.y = DCInp.z
-              aTrack.w.z = DCInp.y
-           elseif(InputP(2:3) .eq. '-y') then              
-              aTrack.w.x = DCInp.x
-              aTrack.w.y = -DCInp.z
-              aTrack.w.z = DCInp.y
-           elseif(InputP(2:3) .eq. '+x') then              
-              aTrack.w.x = DCInp.z
-              aTrack.w.y = DCInp.x
-              aTrack.w.z = DCInp.y
-           elseif(InputP(2:3) .eq. '-x') then              
-              aTrack.w.x = -DCInp.z
-              aTrack.w.y = DCInp.x
-              aTrack.w.z = DCInp.y
-           else
-              write(msg,*)' InputP=',InputP, ' and ',
-     *             InputA,' incompatible'
-              call cerrorMsg(msg, 0)
-           endif
         endif
         return
 c        ***************************
